@@ -20,7 +20,7 @@ Maybe I should learn journalists' shorthand.
 def average(numbers):
     # maybe rewrite this to not materialize the array
     numbers = list(numbers)
-    return sum(numbers) / (len(numbers) or 1)
+    return float(sum(numbers)) / (len(numbers) or 1)
 
 
 def stdev(numbers):
@@ -86,21 +86,4 @@ def analyze(text):
     }
 
 
-
 # cosine distance from works of shakespeare, OTHERS in public domain!
-
-def main():
-
-    criteria = {
-        'average_word_lengths': average_word_lengths,
-        'stdev_word_lengths': stdev_word_lengths,
-        'average_sentence_lengths': average_sentence_lengths,
-        'stdev_sentence_lengths': stdev_sentence_lengths,
-    }
-
-    for name, function in criteria.items():
-        print(name, function(INPUT_TEXT))
-    print()
-
-if __name__ == '__main__':
-    main()
